﻿using System;
using PREPTOOLLib;

namespace toc
{
    class Toc
    {
        static void Main(string[] args)
        {
            string[] Author = new string[50];
            string[] DocTitle = new string[50];
            int[] NumPage = new int[50];
            int pages = 1;

            //引数チェック
            if (args.Length < 3)
            {
                Console.WriteLine("複数の PDF ファイルを統合し、目次を作成します。");
                Console.WriteLine("toc PDF-InputFile1 PDF-InputFile2 ... PDF-OutputFile");
                Environment.Exit(1);
            }
            else if (args.Length > 52)
            {
                Console.WriteLine("引数が多すぎます。５０ファイルまで指定できます。");
                Environment.Exit(2);
            }

            //インスタンス生成
            PDoc doc = new PDoc();

            //出力ファイル
            if (!doc.New("output.pdf", 0, 0))
            {
                Console.WriteLine("'output.pdf'を作成できません");
                Environment.Exit(3);
            }

            //入力ファイルからタイトルと作成者情報を取り出し記憶する
            for (int i = 0; i < (args.Length - 1); i++)
            {
                //入力ファイルをインスタンスにAttachする
                IDoc idoc = new IDoc();
                if (!idoc.Open(args[i], null))
                {
                    Console.WriteLine("ファイルを開けません");
                    Environment.Exit(4);
                }
                doc.Attach(idoc);

                //属性情報
                Author[i] = idoc.GetInfoAttr("Author");
                DocTitle[i] = idoc.GetInfoAttr("Title");

                //総ページ数（次の文書の開始ページにする）
                pages += idoc.NumPages();
                NumPage[i + 1] = pages;

                //ページをコピー
                doc.InputCopyAll();
            }

            //最初のページ
            NumPage[0] = 1;

            //目次のために新たなページを作成
            doc.NewPage();

            //フォントテンプレートを開き、対象のページにアタッチ
            //このテンプレート（PDF）に目的の文字が無い場合は、ASCII 32(space)に置き換わる
            if (!doc.InputOpen("msfonts.pdf"))
            {
                Console.WriteLine("フォントテンプレートを開けません");
                Environment.Exit(5);
            }

            //ページレイヤーのハンドルを取得し、ページサイズをA4(595x842)に設定
            content con = doc.Page();
            doc.PageSize(595, 842);
            con.SetTm(1, 0, 0, 1, 100, 710);
            con.SetFont("Helvetica", 18);
            con.PrintText("Table of Contents", 100, 710);

            //すべてのファイルに対して、
            for (int i = 0; i < (args.Length - 1); i++)
            {
                //作成者と文書タイトルを追加
                if (!con.SetFont("MS-Gothic", 14))
                {
                    Console.WriteLine("フォントを設定できません");
                    Environment.Exit(6);
                }
                con.SetTm(1, 0, 0, 1, 100, 700 - 15 - 15 * (float)i);
                con.PrintText(Author[i], 100, 700 - 15 - 15 * (float)i);
                con.SetTm(1, 0, 0, 1, 250, 700 - 15 - 15 * (float)i);
                con.PrintText(DocTitle[i], 200, 700 - 15 - 15 * (float)i);

                //リンクを追加
                doc.AddGoToLink(NumPage[args.Length - 1], 100, 700 -15 - 15 * (float)i, 400, 700 - 15 * (float)i, NumPage[i], 0, 0, 6, 0);
            }

            //出力ファイルを閉じる
            doc.Close();
        }
    }
}
